#
# spec file for package opa-fm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define git_ver .0.acde83417bb3

%define pseudo_opt %{_prefix}/lib/opa-fm
%define opasysconfdir %{_sysconfdir}/opa-fm/
%define opavarlibdir %{_localstatedir}/usr/lib/opa-fm/
Name:           opa-fm
Version:        10.14.4.0.20
Release:        1.1
Summary:        Intel Omni-Path Fabric Management Software
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            http://www.intel.com/
Source0:        %{name}-%{version}%{git_ver}.tar.gz
Source1:        %{name}-rpmlintrc
Patch1:         opa-fm-Fallback-to-custom-vendor-if-os_vendor-fails.patch
Patch2:         opa-fm-use-RPM_OPT_FLAGS.patch
Patch3:         opa-fm-force-code-symbols-to-be-loaded.patch
Patch5:         opa-fm-harden-systemd-service.patch
BuildRequires:  gcc-c++
BuildRequires:  infiniband-diags-devel
BuildRequires:  libexpat-devel
BuildRequires:  libopenssl-devel
BuildRequires:  ncurses-devel
BuildRequires:  rdma-core-devel
BuildRequires:  tcl-devel
BuildRequires:  zlib-devel
Requires:       infiniband-diags
Requires:       rdma >= 12
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Currently ONLY builds on x86_64
ExclusiveArch:  x86_64

%description
The %{name} contains Intel Omni-Path fabric management applications. This
 includes: the Subnet Manager, Baseboard Manager, Performance Manager,
Fabric Executive, and some fabric management tools.

%prep
%autosetup -p0 -n  %{name}-%{version}%{git_ver}

%build
export RPM_OPT_FLAGS
if [ -d Esm ]; then
	cd Esm
fi
./fmbuild -r -C

%install
# directories
install -d -m0755 %{buildroot}%{opasysconfdir}

install -D -m 644 stage.rpm/opafm.service %{buildroot}%{_prefix}/lib/systemd/system/opafm.service
install -D -m 755 stage.rpm/opafmctrl %{buildroot}/%{pseudo_opt}/bin/opafmctrl
install -D -m 755 stage.rpm/opafmd %{buildroot}/%{pseudo_opt}/bin/opafmd

%if 0%{?rhel} && 0%{?rhel} < 7
install -D -m 755 stage.rpm/opafm %{buildroot}%{_sysconfdir}/init.d/opafm
%endif

install -D -m 644 stage.rpm/opafm.xml  %{buildroot}%{opasysconfdir}/opafm.xml
install -D stage.rpm/fm_capture %{buildroot}/%{pseudo_opt}/bin/fm_capture
install -D stage.rpm/fm_cmd %{buildroot}/%{pseudo_opt}/bin/fm_cmd
install -D stage.rpm/fm_cmdall %{buildroot}/%{pseudo_opt}/bin/fm_cmdall
install -D stage.rpm/smpoolsize %{buildroot}/%{pseudo_opt}/bin/smpoolsize

install -D stage.rpm/sm %{buildroot}/%{pseudo_opt}/runtime/sm
install -D stage.rpm/fe %{buildroot}/%{pseudo_opt}/runtime/fe

install -D stage.rpm/config_check %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/config_check
install -D stage.rpm/config_convert %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/config_convert
install -D stage.rpm/config_diff %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/config_diff
install -D stage.rpm/config_generate %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/config_generate
install -D stage.rpm/opafm %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/opafm
if [ -d Esm ]; then
	sub_dir=Esm/
else
	sub_dir=
fi
install -D -m 644 ${sub_dir}ib/src/linux/startup/opafm_src.xml %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/opafm_src.xml

install -D -m 644 stage.rpm/opafm.xml %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/opafm.xml
install -D stage.rpm/opaxmlextract %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/opaxmlextract
install -D stage.rpm/opaxmlfilter %{buildroot}/%{pseudo_opt}/%{_sysconfdir}/opaxmlfilter

mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}/opt
mkdir -p %{buildroot}%{opavarlibdir}
ln -s /%{pseudo_opt}/bin/fm_cmd %{buildroot}%{_sbindir}/opafmcmd
ln -s /%{pseudo_opt}/bin/fm_cmdall %{buildroot}%{_sbindir}/opafmcmdall
ln -s %{pseudo_opt} %{buildroot}/opt/
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcopafm

%pre
%service_add_pre opafm.service

%post
%service_add_post opafm.service

%preun
%service_del_preun opafm.service

%postun
%service_del_postun opafm.service

%files
%defattr(-,root,root,-)
%dir %{opasysconfdir}
%dir %{pseudo_opt}/
%dir %{pseudo_opt}/bin
%dir %{pseudo_opt}/etc
%dir %{pseudo_opt}/runtime
/opt/opa-fm
%config(noreplace) %{opasysconfdir}/opafm.xml

%doc README
%license LICENSE

%{_prefix}/lib/systemd/system/opafm.service
%{pseudo_opt}/bin/*
%{pseudo_opt}%{_sysconfdir}/*
%{pseudo_opt}/runtime/*
%{_sbindir}/opafmcmd
%{_sbindir}/opafmcmdall
%{_sbindir}/rcopafm

%changelog
* Wed Feb 19 2025 Nicolas Morey <nicolas.morey@suse.com>
- Update to 10.14.4.0.20 (jsc#PED-8565)
  - No changelog available
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Jul 25 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to 10.12.1.0.6
  - No changelog available
* Fri Sep 30 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 10.11.2.0.3
  - No changelog available
- Refresh opa-fm-Fallback-to-custom-vendor-if-os_vendor-fails.patch against latest sources
- Add opa-fm-force-code-symbols-to-be-loaded.patch to fix issues with LTO
* Mon Nov 15 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 10.11.0.2.1 (jsc#SLE-20578)
  - gcc11 fixes
- Drop patches merged upstream:
  - opa-fm-force-code-symbols-to-be-loaded.patch
  - opa-fm-fix-multiple-definitions.patch
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * opa-fm-harden-systemd-service.patch
* Wed Apr 28 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v10.11.0.0.574
  - No changelog available
* Wed Jul 22 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v10.10.3.0.11
  - No changelog available
* Sun Jun  7 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v10.10.1
  - No changelog available
  - Add opa-fm-fix-multiple-definitions.patch to fix compatibility with GCC10
* Thu Sep 26 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v10.9.3.1.1
  - No changelog available
* Thu Sep  5 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v10.9.2.2.1
  * No changelog available
- Drop reproducible.patch as it was fixed upstream
- Mark LICENSE with %%license
- Remove infiniband-diags-devel dependency as it is now provided by rdma-core-devel
- Add opa-fm-force-code-symbols-to-be-loaded.patch to fix around missing
  symbol for version patching when LTO is enabled
* Mon Oct 15 2018 nmoreychaisemartin@suse.com
- Update to v10.8.0.0.202 (fate#325858)
  * No changelog available
* Sat Jul 14 2018 bwiedemann@suse.com
- Add reproducible.patch to fix build date (boo#1047218)
* Tue Jun 12 2018 nmoreychaisemartin@suse.com
- Update to v10.7.0.0.145 (fate#325046)
  * No changelog available
- Rebase opa-fm-use-RPM_OPT_FLAGS.patch and
  opa-fm-Fallback-to-custom-vendor-if-os_vendor-fails.patch to the
  latest sources.
* Mon Dec 18 2017 nmoreychaisemartin@suse.com
- Move /etc/sysconfig/opa* tyo /etc/opa-fm (bsc#1071525)
* Mon Nov 20 2017 nmoreychaisemartin@suse.com
- Update to v10.6.0.0.132
  * No changelog available
- Remove opa-fm-sigset-was-removed.patch as it was fixed upstream.
- Rebase opa-fm-use-RPM_OPT_FLAGS.patch and
  opa-fm-Fallback-to-custom-vendor-if-os_vendor-fails.patch to the
  latest sources.
* Tue Sep 19 2017 nmoreychaisemartin@suse.com
- Update to v10.5.1.0.1
  * No changelog available
- Update opa-fm-Fallback-to-custom-vendor-if-os_vendor-fails.patch
  to the latest sources
* Tue Sep  5 2017 nmoreychaisemartin@suse.com
- Update _service to allow auto updates from github
* Mon Aug 28 2017 nmoreychaisemartin@suse.com
- Update patches to latest sources:
  * opa-fm-use-RPM_OPT_FLAGS.patch
  * 0001-Fall-back-to-custom-vendor-if-os_vendor-fails.patch was renamed
  to opa-fm-Fallback-to-custom-vendor-if-os_vendor-fails.patch
- Add opa-fm-sigset-was-removed.patch to build with the latest glibc
  which does not expose <bits/sigset.h> anymore
* Wed Aug  9 2017 nmoreychaisemartin@suse.com
- Update to v10.4.1.0.2
  * No changelog available
* Fri Jun 23 2017 nmoreychaisemartin@suse.com
- Replace dependency from libibmad-devel to infiniband-diags-devel
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Update to v10.4.0.0.197
  * No changelog available
* Fri May  5 2017 nmoreychaisemartin@suse.com
- Unify spec with SLE12.
- Reenable /opt directory (bsc#1036678).
* Fri Apr 28 2017 nmoreychaisemartin@suse.com
- Update path in /opt (bsc#1036678).
* Mon Apr  3 2017 josef.moellers@suse.com
- Removed a few unneeded dependencies to make rpmlint happy.
  Removed references to /var/usr/lib as it is not FHS.
* Wed Mar 29 2017 pth@suse.de
- Make dependencies on libs now coming from rdma-core versioned.
- Where feasable depend on rdma-core-devel.
* Thu Mar 16 2017 ndas@suse.de
- Add required package dependencies (bsc#1019151).
* Thu Mar 16 2017 josef.moellers@suse.com
- Modified spec file:
  * Removed some redudant code from %%post and %%preun
  * changed opa-fm.rpmlintrc to %%{name}.rpmlintrc
  * removed references to "/opt".
  * renamed opa-fm.rpmlintrc to opa-fm-rpmlintrc
* Tue Feb 28 2017 josef.moellers@suse.com
- Update to v10.3.1
  Unfortunately Intel has not shared any
  information related to the changes
  (fate#321479)
* Thu Jun  2 2016 ndas@suse.de
- Fixed misplaced opafm.info and opafm.xml to their peroper location
  (bsc#982810). This generates suse-filelist-forbidden-sysconfig error
  which requires a rpmlint file to suppress.
  [+opa-fm.rpmlintrc]
* Fri May 27 2016 ndas@suse.de
- Changed package directory(/opt/opafm) to /usr/lib/opafm and
  created a softlink /opt/opafm for the same, this partially fix
  osc warning suse-filelist-forbidden-opt(bsc#982045).
* Wed Mar  9 2016 ndas@suse.de
- Initial package, version: 10.0.0.0.697 (fate#319230)
